pub struct ReconstructionCheckpoint {
pub format_version: u32,
pub completed_iterations: usize,
pub object_spectrum: Array2<Complex64>,
pub pupil: Pupil,
pub illumination_corrections: Option<Vec<(f64, f64)>>,
pub frame_gains: Option<Vec<f64>>,
pub background: Option<Vec<f64>>,
pub algorithm_auxiliary: Option<AlgorithmAuxiliaryState>,
pub history: ReconstructionHistory,
}Expand description
Serializable algorithm state used to resume a reconstruction exactly.
Fields
format_version: u32completed_iterations: usizeobject_spectrum: Array2<Complex64>pupil: Pupilillumination_corrections: Option<Vec<(f64, f64)>>Per-source (row, column) corrections in Fourier-grid pixels.
frame_gains: Option<Vec<f64>>background: Option<Vec<f64>>algorithm_auxiliary: Option<AlgorithmAuxiliaryState>history: ReconstructionHistoryImplementations
Sourceimpl ReconstructionCheckpoint
impl ReconstructionCheckpoint
pub fn capture( completed_iterations: usize, state: &ReconstructionState, history: &ReconstructionHistory, ) -> Self
pub fn save(&self, path: impl AsRef<Path>) -> Result<()>
pub fn load(path: impl AsRef<Path>) -> Result<Self>
Sourcepub fn load_for_problem<M: MeasurementRead>(
path: impl AsRef<Path>,
problem: &ReconstructionProblem<M>,
) -> Result<Self>
pub fn load_for_problem<M: MeasurementRead>( path: impl AsRef<Path>, problem: &ReconstructionProblem<M>, ) -> Result<Self>
Loads a checkpoint and verifies all dimensions and calibration counts against the problem that will resume it.
Sourcepub fn validate(&self) -> Result<()>
pub fn validate(&self) -> Result<()>
Validates integrity that does not depend on a reconstruction problem.
Sourcepub fn validate_for_problem<M: MeasurementRead>(
&self,
problem: &ReconstructionProblem<M>,
) -> Result<()>
pub fn validate_for_problem<M: MeasurementRead>( &self, problem: &ReconstructionProblem<M>, ) -> Result<()>
Validates checkpoint dimensions and calibration variables for problem.